<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

defined('ABSPATH') || exit;

global $options, $sidebar;

$active_sidebar = is_active_sidebar('irk-sidebar-shop') && array_key_exists('shop', $sidebar);
$main_class = 'col-12';

get_header('shop');
get_template_part('partials/main-header');

echo '<div class="container">';
if (isset($_GET['is_amazing']) && $_GET['is_amazing'] == 1) {
    $amazing_image = $options->get_option('amazing-header-image');
    echo '<div class="amazing-header">';
    if ($amazing_image) {
        echo wp_get_attachment_image($amazing_image, 'full');
    } else {
        echo '<img src="' . IRK_IMG_URI . 'amazing-title.svg" width="147" height="34">';
    }
    echo '</div>';
} else {
    if ($options->get_option('catalog-subcat') && !is_shop()) {
        get_template_part('partials/catalog-subcat');
    }
}
echo '<div class="row">';

if ($active_sidebar) {
    $main_class = 'col-12 col-lg-9';

    /**
     * Hook: woocommerce_sidebar.
     *
     * @hooked woocommerce_get_sidebar - 10
     */
    do_action('woocommerce_sidebar');
}

echo '<div class="shop-container ' . $main_class . '">';

/**
 * Hook: woocommerce_before_main_content.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20
 * @hooked WC_Structured_Data::generate_website_data() - 30
 */
do_action('woocommerce_before_main_content');

if (!$options->get_option('catalog-description-end')) {
    get_template_part('partials/products-header');
}

echo '<div class="products-list"><div class="list-header clearfix">';
if (woocommerce_product_loop()) {
    /**
     * Hook: woocommerce_before_shop_loop.
     *
     * @hooked woocommerce_output_all_notices - 10
     * @hooked woocommerce_result_count - 20
     * @hooked woocommerce_catalog_ordering - 30
     */
    do_action('woocommerce_before_shop_loop');
    echo '</div>';
    woocommerce_product_loop_start();
    if (wc_get_loop_prop('total')) {
        while (have_posts()) {
            the_post();

            /**
             * Hook: woocommerce_shop_loop.
             */
            do_action('woocommerce_shop_loop');
            wc_get_template_part('content', 'product');
        }
    }
    woocommerce_product_loop_end();

    /**
     * Hook: woocommerce_after_shop_loop.
     *
     * @hooked woocommerce_pagination - 10
     */
    do_action('woocommerce_after_shop_loop');
} else {
    /**
     * Hook: woocommerce_no_products_found.
     *
     * @hooked wc_no_products_found - 10
     */
    do_action('woocommerce_no_products_found');
}
echo '</div>';
/**
 * Hook: woocommerce_after_main_content.
 *
 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
 */
do_action('woocommerce_after_main_content');

echo '</div>';
echo '</div>';

get_template_part('partials/archive-products-slider');

if ($options->get_option('catalog-description-end')) {
    get_template_part('partials/products-header');
}

echo '</div>';

get_template_part('partials/main-footer');
get_footer('shop');