<?php
/**
 * Mini-cart
 *
 * Contains the markup for the mini-cart, used by the cart widget.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/mini-cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 5.2.0
 */

defined('ABSPATH') || exit;

global $labels, $options;

?>
<div class="mini-cart-header clearfix">
    <span class="count"><?php echo WC()->cart->cart_contents_count . ' ' . esc_html($labels->get_label('products')); ?></span>
    <a href="<?php echo wc_get_cart_url(); ?>" class="cart"><?php echo esc_html($labels->get_label('view-cart')); ?></a>
</div>
<?php
do_action('woocommerce_before_mini_cart'); ?>

<?php if (!WC()->cart->is_empty()) : ?>

    <div class="woocommerce-cart-form woocommerce-mini-cart cart_list product_list_widget <?php echo esc_attr($args['list_class']); ?>">
        <div class="cart-form-contents">
            <?php
            do_action('woocommerce_before_mini_cart_contents');

            foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
                $_product = apply_filters('woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key);
                $product_id = apply_filters('woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key);

                if ($_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters('woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key)) {
                    $product_name = apply_filters('woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key);
                    $thumbnail = apply_filters('woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key);
                    $product_price = apply_filters('woocommerce_cart_item_price', WC()->cart->get_product_price($_product), $cart_item, $cart_item_key);
                    $product_permalink = apply_filters('woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink($cart_item) : '', $cart_item, $cart_item_key);
                    $quantity = apply_filters('woocommerce_widget_cart_item_quantity', '<span class="quantity">' . $cart_item['quantity'] . '</span>', $cart_item, $cart_item_key);
                    ?>
                    <div class="woocommerce-mini-cart-item cart-item <?php echo esc_attr(apply_filters('woocommerce_mini_cart_item_class', 'mini_cart_item', $cart_item, $cart_item_key)); ?>">
                        <div class="col-image">
                            <?php echo $thumbnail; ?>
                            <div class="sale-flash">
                                <?php
                                if (intval(irk_is_product_amazing($product_id)) > 0) {
                                    $amazing_image = $options->get_option('amazing-image');
                                    echo $amazing_image ? wp_get_attachment_image($amazing_image) : '<img src="' . IRK_IMG_URI . 'amazing.svg" width="108" height="13" alt="amazing">';
                                } elseif ($_product->is_on_sale()) {
                                    $onsale_image = $options->get_option('onsale-image');
                                    echo $onsale_image ? wp_get_attachment_image($onsale_image) : '<img src="' . IRK_IMG_URI . 'onsale.svg" width="60" height="13" alt="onsale">';
                                }
                                ?>
                            </div>
                        </div>
                        <div class="col-product">
                            <?php if (empty($product_permalink)) : ?>
                                <?php echo '<span class="product-name"' . wp_kses_post($product_name) . '</span>'; ?>
                            <?php else : ?>
                                <a href="<?php echo esc_url($product_permalink); ?>" class="product-name">
                                    <?php echo wp_kses_post($product_name); ?>
                                </a>
                            <?php endif; ?>
                            <div class="product-price"><?php echo $quantity . '&nbsp;&times;&nbsp;' . $product_price; ?></div>
                            <?php echo wc_get_formatted_cart_item_data($cart_item); ?>
                            <?php echo irk_get_product_info($_product); ?>
                            <div class="product-actions">
                                <?php
                                echo apply_filters(
                                    'woocommerce_cart_item_remove_link',
                                    sprintf(
                                        '<a href="%s" class="remove remove_from_cart_button" aria-label="%s" data-product_id="%s" data-cart_item_key="%s" data-product_sku="%s"><span data-icon="Icon-Navigation-Close"></span>' . esc_html__('Remove this item', 'woocommerce') . '</a>',
                                        esc_url(wc_get_cart_remove_url($cart_item_key)),
                                        esc_attr__('Remove this item', 'woocommerce'),
                                        esc_attr($product_id),
                                        esc_attr($cart_item_key),
                                        esc_attr($_product->get_sku())
                                    ),
                                    $cart_item_key
                                );
                                ?>
                            </div>
                        </div>
                    </div>
                    <?php
                }
            }

            do_action('woocommerce_mini_cart_contents');
            ?>
        </div>
    </div>
    <div class="mini-cart-footer clearfix">
        <p class="woocommerce-mini-cart__total total">
            <?php
            /**
             * Hook: woocommerce_widget_shopping_cart_total.
             *
             * @hooked woocommerce_widget_shopping_cart_subtotal - 10
             */
            do_action('woocommerce_widget_shopping_cart_total');
            ?>
        </p>
        <?php do_action('woocommerce_widget_shopping_cart_before_buttons'); ?>
        <p class="woocommerce-mini-cart__buttons buttons"><?php do_action('woocommerce_widget_shopping_cart_buttons'); ?></p>
        <?php do_action('woocommerce_widget_shopping_cart_after_buttons'); ?>
    </div>
<?php else : ?>
    <p class="woocommerce-mini-cart__empty-message"><?php esc_html_e('No products in the cart.', 'woocommerce'); ?></p>
<?php endif; ?>
<?php
do_action('woocommerce_after_mini_cart');