<?php
/**
 * My Account Dashboard
 *
 * Shows the first intro screen on the account dashboard.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/dashboard.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 4.4.0
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

global $labels;

$allowed_html = array(
    'a' => array(
        'href' => array(),
    ),
);

$args = array(
    'post_type' => 'product',
    'post_status' => 'publish',
    'posts_per_page' => 10,
    'meta_key' => '_stock_status',
    'meta_value' => 'instock',
    'meta_compare' => '=',
);
$products = new WP_Query($args);
?>
    <div class="user-welcome">
        <div>
            <span data-icon="Icon-Alert-Info-Fill"></span>
            <?php printf(wp_kses(__('Hello %1$s (not %1$s? <a href="%2$s">Log out</a>)', 'woocommerce'), $allowed_html), esc_html($current_user->display_name), esc_url(wc_logout_url())); ?>
        </div>
        <a href="<?php echo esc_url(wc_customer_edit_account_url()); ?>" class="account-details">
            <?php _e('Account details', 'woocommerce') ?>
            <span data-icon="chevron-<?php echo is_rtl() ? 'left' : 'right'; ?>"></span>
        </a>
    </div>
    <div class="orders-summary">
        <h3 class="content-title">
            <span><?php _e('Orders', 'woocommerce'); ?></span>
            <a href="<?php echo esc_url(wc_get_endpoint_url('orders')); ?>">
                <?php echo esc_html($labels->get_label('view-all')); ?>
                <span data-icon="chevron-<?php echo is_rtl() ? 'left' : 'right'; ?>"></span>
            </a>
        </h3>
        <div class="summary-content">
            <div>
                <div>
                    <img src="<?php echo IRK_IMG_URI; ?>status-processing.svg" width="64" height="64" alt="status-processing">
                </div>
                <div>
                    <strong>
                        <?php echo esc_html(count(irk_get_customer_orders('wc-processing'))); ?>
                        &nbsp;<?php _e('Order', 'woocommerce'); ?>
                    </strong>
                    <span><?php _e('Processing', 'woocommerce'); ?></span>
                </div>
            </div>
            <div>
                <div>
                    <img src="<?php echo IRK_IMG_URI; ?>status-delivered.svg" width="64" height="64" alt="status-delivered">
                </div>
                <div>
                    <strong>
                        <?php echo esc_html(count(irk_get_customer_orders('wc-completed'))); ?>
                        &nbsp;<?php _e('Order', 'woocommerce'); ?>
                    </strong>
                    <span><?php _e('Completed', 'woocommerce'); ?></span>
                </div>
            </div>
            <div>
                <div>
                    <img src="<?php echo IRK_IMG_URI; ?>status-returned.svg" width="64" height="64" alt="status-returned">
                </div>
                <div>
                    <strong>
                        <?php echo esc_html(count(irk_get_customer_orders('wc-refunded'))); ?>
                        &nbsp;<?php _e('Order', 'woocommerce'); ?>
                    </strong>
                    <span><?php _e('Refunded', 'woocommerce'); ?></span>
                </div>
            </div>
        </div>
    </div>
    <div class="last-products widget-products-slider widget">
        <h3 class="content-title"><span><?php echo esc_html($labels->get_label('products')); ?></span></h3>
        <div class="slider-inner">
            <div class="owl-carousel active-carousel">
                <?php while ($products->have_posts()) : ?>
                    <?php
                    $products->the_post();
                    $product_id = $products->post->ID;
                    $product = wc_get_product($product_id);
                    ?>
                    <div <?php wc_product_class('item', $product_id); ?>>
                        <a href="<?php echo $product->get_permalink(); ?>" title="<?php echo $product->get_name(); ?>">
                            <div class="img-wrapper">
                                <?php echo $product->get_image('woocommerce_thumbnail', ['class' => 'img-fluid']); ?>
                            </div>
                            <h4 class="title"><?php echo $product->get_name(); ?></h4>
                            <?php echo $product->get_price_html(); ?>
                        </a>
                    </div>
                <?php endwhile; ?>
                <?php wp_reset_postdata(); ?>
            </div>
        </div>
    </div>
<?php
/**
 * My Account dashboard.
 *
 * @since 2.6.0
 */
do_action('woocommerce_account_dashboard');

/**
 * Deprecated woocommerce_before_my_account action.
 *
 * @deprecated 2.6.0
 */
do_action('woocommerce_before_my_account');

/**
 * Deprecated woocommerce_after_my_account action.
 *
 * @deprecated 2.6.0
 */
do_action('woocommerce_after_my_account');