<?php
/**
 * Orders
 *
 * Shows orders on the account page.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/orders.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.7.0
 */

defined('ABSPATH') || exit;

global $labels;
$statuses = wc_get_order_statuses();
$order_status = $_GET['order-status'] ?? 'all';
$tab = 'all';
if (in_array($order_status, array_keys(wc_get_order_statuses()))) $tab = $order_status;

do_action('woocommerce_before_account_orders', $has_orders);
echo '<div class="myaccount-orders">';
echo '<h3 class="content-title"><span>' . __('Orders', 'woocommerce') . '</span></h3>';
?>
    <div class="orders-tab">
        <a href="<?php echo remove_query_arg('order-status'); ?>" class="<?php echo $tab == 'all' ? 'active' : ''; ?>">
            <?php echo esc_html($labels->get_label('all-orders')); ?>
            <span class="count"><?php echo esc_html(count(irk_get_customer_orders())); ?></span>
        </a>
        <?php foreach ($statuses as $name => $label): ?>
            <a href="<?php echo add_query_arg(['order-status' => $name]); ?>" class="<?php echo $tab == $name ? 'active' : ''; ?>">
                <?php echo esc_html($label); ?>
                <span class="count"><?php echo esc_html(count(irk_get_customer_orders($name))); ?></span>
            </a>
        <?php endforeach; ?>
    </div>
<?php
if ($has_orders) {
    foreach ($customer_orders->orders as $customer_order) {
        $order = wc_get_order($customer_order);
        $item_count = $order->get_item_count() - $order->get_item_count_refunded();
        ?>
        <div class="myaccount-order <?php echo esc_attr($order->get_status()); ?>">
            <div class="order-status">
                <span class="status-name"><?php echo esc_html(wc_get_order_status_name($order->get_status())); ?></span>
                <span data-icon="chevron-<?php echo is_rtl() ? 'left' : 'right'; ?>"></span>
            </div>
            <div class="order-details">
                <div class="order-date">
                    <time datetime="<?php echo esc_attr($order->get_date_created()->date('c')); ?>"><?php echo esc_html(wc_format_datetime($order->get_date_created())); ?></time>
                </div>
                <div class="order-number">
                    <span class="label"><?php _e('Order', 'woocommerce') ?></span>
                    <a href="<?php echo esc_url($order->get_view_order_url()); ?>"><?php echo esc_html($order->get_order_number()); ?></a>
                </div>
                <div class="order-total">
                    <span class="label"><?php _e('Total', 'woocommerce') ?></span>
                    <?php echo wp_kses_post($order->get_formatted_order_total()); ?>
                </div>
                <div class="order-count">
                    <?php echo esc_html($item_count); ?>
                    <span class="label"><?php _e('Items', 'woocommerce') ?></span>
                </div>
            </div>
            <div class="order-items">
                <?php if (count($order->get_items()) > 0) : ?>
                    <?php foreach ($order->get_items() as $item_id => $item) : ?>
                        <?php
                        $product = $item->get_product();
                        if ($product) {
                            echo '<a href="' . $product->get_permalink() . '" title="' . $product->get_name() . '" target="_blank">';
                            echo $product->get_image('woocommerce_gallery_thumbnail');
                            echo '</a>';
                        }
                        ?>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>
            <div class="order-actions">
                <?php
                $actions = wc_get_account_orders_actions($order);
                if (!empty($actions)) {
                    foreach ($actions as $key => $action) {
                        echo '<a href="' . esc_url($action['url']) . '" class="' . sanitize_html_class($key) . '">' . esc_html($action['name']) . '</a>';
                    }
                }
                ?>
            </div>
        </div>
        <?php
    }
    ?>
    <?php do_action('woocommerce_before_account_orders_pagination'); ?>
    <?php if (1 < $customer_orders->max_num_pages) : ?>
        <div class="woocommerce-pagination woocommerce-pagination--without-numbers woocommerce-Pagination">
            <?php if (1 !== $current_page) : ?>
                <a class="woocommerce-button woocommerce-button--previous woocommerce-Button woocommerce-Button--previous" href="<?php echo esc_url(wc_get_endpoint_url('orders', $current_page - 1)); ?>">
                    <span data-icon="chevron-<?php echo is_rtl() ? 'right' : 'left'; ?>"></span>
                    <?php esc_html_e('Previous', 'woocommerce'); ?>
                </a>
            <?php endif; ?>
            <?php if (intval($customer_orders->max_num_pages) !== $current_page) : ?>
                <a class="woocommerce-button woocommerce-button--next woocommerce-Button woocommerce-Button--next" href="<?php echo esc_url(wc_get_endpoint_url('orders', $current_page + 1)); ?>">
                    <?php esc_html_e('Next', 'woocommerce'); ?>
                    <span data-icon="chevron-<?php echo is_rtl() ? 'left' : 'right'; ?>"></span>
                </a>
            <?php endif; ?>
        </div>
    <?php endif; ?>
    <?php
} else {
    echo '<p class="no-items">';
    echo '<img src="' . IRK_IMG_URI . 'order-empty.svg" width="200" height="150" alt="order-empty">';
    echo '<span>' . esc_html($labels->get_label('no-items-found')) . '</span>';
    echo '</p>';
}
echo '</div>';
do_action('woocommerce_after_account_orders', $has_orders);