<?php
/**
 * View Order
 *
 * Shows the details of a particular order on the account page.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/view-order.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.0.0
 */

defined('ABSPATH') || exit;

$notes = $order->get_customer_order_notes();
?>
<div class="myaccount-view-order">
    <h3 class="content-title">
        <span data-icon="Icon-Navigation-Arrow-<?php echo is_rtl() ? 'Right' : 'Left'; ?>"></span>
        <span><?php esc_html_e('Order details', 'woocommerce'); ?></span>
    </h3>
    <div class="order-details">
        <div class="order-date">
            <span class="label"><?php _e('Date', 'woocommerce') ?></span>
            <time datetime="<?php echo esc_attr($order->get_date_created()->date('c')); ?>"><?php echo esc_html(wc_format_datetime($order->get_date_created())); ?></time>
        </div>
        <div class="order-number">
            <span class="label"><?php _e('Order', 'woocommerce') ?></span>
            <span><?php echo esc_html($order->get_order_number()); ?></span>
        </div>
        <div class="order-status">
            <span class="label"><?php _e('Status', 'woocommerce') ?></span>
            <span><?php echo esc_html(wc_get_order_status_name($order->get_status())); ?></span>
        </div>
    </div>
    <?php if ($notes) : ?>
        <ul class="woocommerce-OrderUpdates commentlist notes">
            <?php foreach ($notes as $note) : ?>
                <li class="woocommerce-OrderUpdate comment note">
                    <div class="woocommerce-OrderUpdate-inner comment_container">
                        <div class="woocommerce-OrderUpdate-text comment-text">
                            <p class="woocommerce-OrderUpdate-meta meta"><?php echo date_i18n('Y-m-d H:i:s', strtotime($note->comment_date)); ?></p>
                            <div class="woocommerce-OrderUpdate-description description">
                                <?php echo wpautop(wptexturize($note->comment_content)); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
                            </div>
                            <div class="clear"></div>
                        </div>
                        <div class="clear"></div>
                    </div>
                </li>
            <?php endforeach; ?>
        </ul>
    <?php endif; ?>
    <?php do_action('woocommerce_view_order', $order_id); ?>
</div>