<?php
/**
 * Order Item Details
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/order/order-details-item.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 5.2.0
 */

if (!defined('ABSPATH')) {
    exit;
}

if (!apply_filters('woocommerce_order_item_visible', true, $item)) {
    return;
}

global $labels;

?>
<div class="order-item">
    <?php
    $is_visible = $product && $product->is_visible();
    $product_permalink = apply_filters('woocommerce_order_item_permalink', $is_visible ? $product->get_permalink($item) : '', $item, $order);
    $qty = $item->get_quantity();
    $refunded_qty = $order->get_qty_refunded_for_item($item_id);
    if ($refunded_qty) {
        $qty_display = '<del>' . esc_html($qty) . '</del> <ins>' . esc_html($qty - ($refunded_qty * -1)) . '</ins>';
    } else {
        $qty_display = esc_html($qty);
    }
    ?>
    <div class="product-img">
        <div class="img-wrapper">
            <?php
            echo $product->get_image('woocommerce_thumbnail');
            echo apply_filters('woocommerce_order_item_quantity_html', ' <span class="product-quantity">' . $qty_display . '</span>', $item);
            ?>
        </div>
        <a href="<?php echo wp_kses_post($product_permalink); ?>" target="_blank"><span data-icon="cart-header"></span></a>
    </div>
    <div class="product-name">
        <h4 class="product-title"><?php echo wp_kses_post(apply_filters('woocommerce_order_item_name', $product_permalink ? sprintf('<a href="%s">%s</a>', $product_permalink, $item->get_name()) : $item->get_name(), $item, $is_visible)); ?></h4>
        <?php echo irk_get_product_info($product); ?>
        <div class="item-meta">
            <?php
            do_action('woocommerce_order_item_meta_start', $item_id, $item, $order, false);
            wc_display_item_meta($item);
            do_action('woocommerce_order_item_meta_end', $item_id, $item, $order, false);
            ?>
        </div>
        <?php if ($show_purchase_note && $purchase_note) : ?>
            <div class="purchase-note"><?php echo wpautop(do_shortcode(wp_kses_post($purchase_note))); ?></div>
        <?php endif; ?>
        <?php echo $order->get_formatted_line_subtotal($item); ?>
        <div class="view-product"><a href="<?php echo wp_kses_post($product_permalink); ?>" target="_blank"><?php echo esc_html($labels->get_label('view-product')); ?></a></div>
    </div>
</div>