<?php
/**
 * Order Downloads.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/order/order-downloads.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.3.0
 */

if (!defined('ABSPATH')) {
    exit;
}

global $labels;

?>
<?php if (isset($show_title)) : ?>
    <h6 class="woocommerce-order-downloads__title"><?php esc_html_e('Downloads', 'woocommerce'); ?></h6>
<?php endif; ?>
<div class="order-items dowload-items">
    <?php foreach ($downloads as $download) : ?>
        <?php
        $product_id = $download['product_id'];
        $product = wc_get_product($product_id);
        ?>
        <div class="order-item">
            <div class="product-img">
                <div class="img-wrapper"><?php echo $product->get_image('woocommerce_thumbnail'); ?></div>
                <a href="<?php echo $download['download_url'] ? esc_url($download['download_url']) : '#'; ?>" target="_blank"><span data-icon="download"></span></a>
            </div>
            <div class="product-name">
                <h4 class="product-title"><?php echo esc_html($download['product_name']); ?></h4>
                <div class="download-name"><?php echo esc_html($download['download_name']); ?></div>
                <div class="downloads-remaining">
                    <span class="label"><?php _e('Downloads remaining', 'woocommerce'); ?></span>
                    <span><?php echo is_numeric($download['downloads_remaining']) ? esc_html($download['downloads_remaining']) : esc_html__('&infin;', 'woocommerce'); ?></span>
                </div>
                <div class="access-expires">
                    <span class="label"><?php _e('Expires', 'woocommerce'); ?></span>
                    <span>
                        <?php
                        if (!empty($download['access_expires'])) {
                            echo '<time datetime="' . esc_attr(date('Y-m-d', strtotime($download['access_expires']))) . '" title="' . esc_attr(strtotime($download['access_expires'])) . '">' . esc_html(date_i18n(get_option('date_format'), strtotime($download['access_expires']))) . '</time>';
                        } else {
                            esc_html_e('Never', 'woocommerce');
                        }
                        ?>
                    </span>
                </div>
                <div class="view-product">
                    <a href="<?php echo wp_kses_post($product->get_permalink()); ?>" target="_blank"><?php echo esc_html($labels->get_label('view-product')); ?></a>
                </div>
            </div>
        </div>
    <?php endforeach; ?>
</div>