<?php
/**
 * The Template for displaying all single products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce/Templates
 * @version     1.6.4
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

global $options, $sidebar;

$active_sidebar = is_active_sidebar('irk-sidebar') && array_key_exists('product', $sidebar);

get_header('shop');
get_template_part('partials/main-header');
?>
    <div class="container">
        <div class="row">
            <?php $active_sidebar ? get_sidebar() : null; ?>
            <div class="product-content col-12 <?php echo $active_sidebar ? 'col-lg-9' : null; ?>">
                <?php
                /**
                 * woocommerce_before_main_content hook.
                 *
                 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
                 * @hooked woocommerce_breadcrumb - 20
                 */
                do_action('woocommerce_before_main_content');
                ?>
                <?php while (have_posts()) : ?>
                    <?php the_post(); ?>
                    <?php
                    if ($options->get_option('out-of-stock-related-at-top') && !$product->is_in_stock()) {
                        remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
                        add_action('woocommerce_before_single_product', 'woocommerce_output_related_products', 11);
                    }
                    ?>
                    <?php wc_get_template_part('content', 'single-product'); ?>
                <?php endwhile; // end of the loop. ?>
                <?php
                /**
                 * woocommerce_after_main_content hook.
                 *
                 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
                 */
                do_action('woocommerce_after_main_content');
                ?>
            </div>
        </div>
    </div>
<?php
get_template_part('partials/main-footer');
get_footer('shop');